@@ -38,6 +38,7 @@ class Money
         rules = {}
       elsif rules.size == 1
         rules = rules.pop
+        rules = rules.dup if rules.is_a?(Hash)
 
         if rules.is_a?(Symbol)
           warn '[DEPRECATION] Use Hash when passing rules to Money#format.'
@@ -78,6 +79,8 @@ class Money
     end
 
     def determine_format_from_formatting_rules(rules)
+      return currency.format if currency.format && !rules.has_key?(:symbol_position)
+
       symbol_position = symbol_position_from(rules)
 
       if symbol_position == :before
