@@ -19,13 +19,13 @@ def reset_i18n
   I18n.backend = I18n::Backend::Simple.new
 end
 
-RSpec.shared_context "with infinite precision", :infinite_precision do
+RSpec.shared_context "with infinite precision", :default_infinite_precision_true do
   before do
-    Money.infinite_precision = true
+    Money.default_infinite_precision = true
   end
 
   after do
-    Money.infinite_precision = false
+    Money.default_infinite_precision = false
   end
 end
 
